@@ -24,15 +24,15 @@ const char* FILE_NAME = "Sys/IO.c";
 
 int32_t SPVM__Sys__IO__INIT_STDIN(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   FILE* stream = stdin;
   
-  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
 
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
   
@@ -41,15 +41,15 @@ int32_t SPVM__Sys__IO__INIT_STDIN(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__INIT_STDOUT(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   FILE* stream = stdout;
   
-  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
   
@@ -58,16 +58,16 @@ int32_t SPVM__Sys__IO__INIT_STDOUT(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__INIT_STDERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   FILE* stream = stderr;
   
-  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
   
@@ -79,7 +79,7 @@ int32_t SPVM__Sys__IO__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_path = stack[0].oval;
   
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t flags = stack[1].ival;
@@ -102,25 +102,25 @@ int32_t SPVM__Sys__IO__open(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t fd = stack[0].ival;
   
   void* obj_buf = stack[1].oval;
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$buf must be defined", __func__, FILE_NAME, __LINE__);
   }
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
   int32_t buf_length = env->length(env, stack, obj_buf);
   
   int32_t count = stack[2].ival;
   if (!(count >= 0)) {
-    return env->die(env, stack, "The $count must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$count must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t buf_offset = stack[3].ival;
   if (!(count <= buf_length - buf_offset)) {
-    return env->die(env, stack, "The $count must be less than the length of the $buf - the $buf_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$count must be less than the length of $buf - $buf_offset", __func__, FILE_NAME, __LINE__);
   }
   
   errno = 0;
@@ -137,26 +137,32 @@ int32_t SPVM__Sys__IO__read(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t fd = stack[0].ival;
   
   void* obj_buf = stack[1].oval;
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$buf must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
   int32_t buf_length = env->length(env, stack, obj_buf);
-
+  
   int32_t count = stack[2].ival;
-  if (!(count >= 0)) {
-    return env->die(env, stack, "The $count must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
-  }
   
   int32_t buf_offset = stack[3].ival;
+  
+  if (!(buf_offset >= 0)) {
+    return env->die(env, stack, "$buf_offse must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+  }
+  
+  if (count < 0) {
+    count = buf_length - buf_offset;
+  }
+  
   if (!(count <= buf_length - buf_offset)) {
-    return env->die(env, stack, "The $count must be less than the length of the $buf - the $buf_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$count must be less than the length of $buf - $buf_offset", __func__, FILE_NAME, __LINE__);
   }
   
   errno = 0;
@@ -178,7 +184,7 @@ int32_t SPVM__Sys__IO__lseek(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t offset = stack[1].lval;
   
   if (!(offset >= 0)) {
-    return env->die(env, stack, "The $offset must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$offset must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
 
   int32_t whence = stack[2].ival;
@@ -214,17 +220,17 @@ int32_t SPVM__Sys__IO__close(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
 
   void* obj_mode = stack[1].oval;
   if (!obj_mode) {
-    return env->die(env, stack, "The $mode must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$mode must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* mode = env->get_chars(env, stack, obj_mode);
   
@@ -236,8 +242,8 @@ int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
-  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
   
@@ -246,14 +252,14 @@ int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t fd = stack[0].ival;
   
   void* obj_mode = stack[1].oval;
   
   if (!obj_mode) {
-    return env->die(env, stack, "The $mode must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$mode must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* mode = env->get_chars(env, stack, obj_mode);
@@ -265,8 +271,8 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
-  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
   
@@ -278,7 +284,7 @@ int32_t SPVM__Sys__IO__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -297,34 +303,34 @@ int32_t SPVM__Sys__IO__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__fread(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_ptr = stack[0].oval;
   
   if (!obj_ptr) {
-    return env->die(env, stack, "The $ptr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$ptr must be defined", __func__, FILE_NAME, __LINE__);
   }
   char* ptr = (char*)env->get_chars(env, stack, obj_ptr);
   int32_t ptr_length = env->length(env, stack, obj_ptr);
   
   int32_t size = stack[1].ival;
   if (!(size >= 0)) {
-    return env->die(env, stack, "The $size must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$size must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t nmemb = stack[2].ival;
   if (!(nmemb >= 0)) {
-    return env->die(env, stack, "The $nmemb must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$nmemb must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_stream = stack[3].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t ptr_offset = stack[4].ival;
   if (!(nmemb * size <= ((ptr_length - ptr_offset))  )) {
-    return env->die(env, stack, "The $nmemb * the $size must be less than or equal to the length of the $ptr - $ptr_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$nmemb * $size must be less than or equal to the length of $ptr - $ptr_offset", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -341,7 +347,7 @@ int32_t SPVM__Sys__IO__feof(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -358,7 +364,7 @@ int32_t SPVM__Sys__IO__ferror(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -375,7 +381,7 @@ int32_t SPVM__Sys__IO__clearerr(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -387,12 +393,12 @@ int32_t SPVM__Sys__IO__clearerr(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__getc(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -406,29 +412,29 @@ int32_t SPVM__Sys__IO__getc(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__fgets(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_s = stack[0].oval;
   if (!obj_s) {
-    return env->die(env, stack, "The $s must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$s must be defined", __func__, FILE_NAME, __LINE__);
   }
   char* s = (char*)env->get_chars(env, stack, obj_s);
   int32_t s_length = env->length(env, stack, obj_s);
   
   int32_t size = stack[1].ival;
   if (!(size >= 0)) {
-    return env->die(env, stack, "The $size must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$size must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_stream = stack[2].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t s_offset = stack[3].ival;
   
   if (!(size <= s_length - s_offset)) {
-    return env->die(env, stack, "The $size must be less than the length of the $s - the $s_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$size must be less than the length of $s - $s_offset", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -447,33 +453,33 @@ int32_t SPVM__Sys__IO__fgets(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__fwrite(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_ptr = stack[0].oval;
   if (!obj_ptr) {
-    return env->die(env, stack, "The $ptr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$ptr must be defined", __func__, FILE_NAME, __LINE__);
   }
   char* ptr = (char*)env->get_chars(env, stack, obj_ptr);
   int32_t ptr_length = env->length(env, stack, obj_ptr);
   
   int32_t size = stack[1].ival;
   if (!(size >= 0)) {
-    return env->die(env, stack, "The $size must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$size must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t nmemb = stack[2].ival;
   if (!(nmemb >= 0)) {
-    return env->die(env, stack, "The $nmemb must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$nmemb must be more than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_stream = stack[3].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   int32_t ptr_offset = stack[4].ival;
   if (!(nmemb * size <= ((ptr_length - ptr_offset))  )) {
-    return env->die(env, stack, "The $nmemb * the $size must be less than or equal to the length of the $ptr - $ptr_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$nmemb * $size must be less than or equal to the length of $ptr - $ptr_offset", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -487,12 +493,12 @@ int32_t SPVM__Sys__IO__fwrite(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__fclose(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -504,8 +510,8 @@ int32_t SPVM__Sys__IO__fclose(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "closed", 1, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  env->set_field_byte_by_name(env, stack, obj_stream, "closed", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].ival = status;
   
@@ -517,7 +523,7 @@ int32_t SPVM__Sys__IO__fseek(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -525,7 +531,7 @@ int32_t SPVM__Sys__IO__fseek(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t offset = stack[1].lval;
   
   if (!(offset >= 0)) {
-    return env->die(env, stack, "The $offset must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$offset must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
 
   int32_t whence = stack[2].ival;
@@ -547,7 +553,7 @@ int32_t SPVM__Sys__IO__ftell(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -569,7 +575,7 @@ int32_t SPVM__Sys__IO__fflush(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = stack[0].oval;
   
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
@@ -614,7 +620,7 @@ int32_t SPVM__Sys__IO__mkdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_path = stack[0].oval;
   
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* path = env->get_chars(env, stack, obj_path);
@@ -655,7 +661,7 @@ int32_t SPVM__Sys__IO__rmdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_path = stack[0].oval;
   
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* path = env->get_chars(env, stack, obj_path);
@@ -677,7 +683,7 @@ int32_t SPVM__Sys__IO__unlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_pathname = stack[0].oval;
 
   if (!obj_pathname) {
-    return env->die(env, stack, "The $pathname must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$pathname must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* pathname = env->get_chars(env, stack, obj_pathname);
@@ -696,12 +702,12 @@ int32_t SPVM__Sys__IO__unlink(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_oldpath = stack[0].oval;
   
   if (!obj_oldpath) {
-    return env->die(env, stack, "The $oldpath must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$oldpath must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* oldpath = env->get_chars(env, stack, obj_oldpath);
@@ -709,7 +715,7 @@ int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_newpath = stack[1].oval;
   
   if (!obj_newpath) {
-    return env->die(env, stack, "The $newpath must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$newpath must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* newpath = env->get_chars(env, stack, obj_newpath);
@@ -728,14 +734,14 @@ int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_buf = stack[0].oval;
 
   int32_t size = stack[1].ival;
 
   if (!(size >= 0)) {
-    return env->die(env, stack, "The $size must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$size must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   char* ret_buf;
@@ -743,7 +749,7 @@ int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
     char* buf = (char*)env->get_chars(env, stack, obj_buf);
     int32_t buf_length = env->length(env, stack, obj_buf);
     if (!(size <= buf_length)) {
-      return env->die(env, stack, "The $size must be less than or equal to the lenght of the $buf", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$size must be less than or equal to the lenght of $buf", __func__, FILE_NAME, __LINE__);
     }
     
     errno = 0;
@@ -773,7 +779,7 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "_getdcwd is not supported in this system(!defined(_WIN32))", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t drive = stack[0].ival;
   
@@ -782,7 +788,7 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t maxlen = stack[2].ival;
 
   if (!(maxlen > 0)) {
-    return env->die(env, stack, "The $maxlen must be greater than 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$maxlen must be greater than 0", __func__, FILE_NAME, __LINE__);
   }
   
   char* ret_buffer;
@@ -790,7 +796,7 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
     char* buffer = (char*)env->get_chars(env, stack, obj_buffer);
     int32_t buffer_length = env->length(env, stack, obj_buffer);
     if (!(maxlen <= buffer_length)) {
-      return env->die(env, stack, "The $maxlen must be less than or equal to the lenght of the $buffer", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$maxlen must be less than or equal to the lenght of $buffer", __func__, FILE_NAME, __LINE__);
     }
     
     errno = 0;
@@ -825,7 +831,7 @@ int32_t SPVM__Sys__IO__realpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_path = stack[0].oval;
   
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   const char* path = env->get_chars(env, stack, obj_path);
@@ -868,7 +874,7 @@ int32_t SPVM__Sys__IO___fullpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_relPath = stack[1].oval;
 
   if (!obj_relPath) {
-    return env->die(env, stack, "The $relPath must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$relPath must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   char* relPath = (char*)env->get_chars(env, stack, obj_relPath);
@@ -905,7 +911,7 @@ int32_t SPVM__Sys__IO__chdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
   
@@ -925,7 +931,7 @@ int32_t SPVM__Sys__IO__chmod(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
 
@@ -951,7 +957,7 @@ int32_t SPVM__Sys__IO__chown(SPVM_ENV* env, SPVM_VALUE* stack) {
 #else
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
 
@@ -976,13 +982,13 @@ int32_t SPVM__Sys__IO__truncate(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
 
   int64_t length = stack[1].lval;
   if (!(length >= 0)) {
-    return env->die(env, stack, "The $length must be less than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$length must be less than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
 
   errno = 0;
@@ -1002,17 +1008,17 @@ int32_t SPVM__Sys__IO__symlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "symlink is not supported in this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_oldpath = stack[0].oval;
   if (!obj_oldpath) {
-    return env->die(env, stack, "The $oldpath must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$oldpath must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* oldpath = env->get_chars(env, stack, obj_oldpath);
 
   void* obj_newpath = stack[1].oval;
   if (!obj_newpath) {
-    return env->die(env, stack, "The $newpath must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$newpath must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* newpath = env->get_chars(env, stack, obj_newpath);
   
@@ -1034,27 +1040,27 @@ int32_t SPVM__Sys__IO__readlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "readlink is not supported in this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
 
   void* obj_buf = stack[1].oval;
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$buf must be defined", __func__, FILE_NAME, __LINE__);
   }
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
   int32_t buf_length = env->length(env, stack, obj_buf);
   
   int32_t bufsiz = stack[2].ival;
   if (!(bufsiz >= 0)) {
-    return env->die(env, stack, "The $bufsiz must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$bufsiz must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   if (!(bufsiz <= buf_length)) {
-    return env->die(env, stack, "The $bufsiz must be less than or equal to the length of the $buf", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$bufsiz must be less than or equal to the length of $buf", __func__, FILE_NAME, __LINE__);
   }
   
   errno = 0;
@@ -1072,11 +1078,11 @@ int32_t SPVM__Sys__IO__readlink(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_dir = stack[0].oval;
   if (!obj_dir) {
-    return env->die(env, stack, "The $dir must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dir must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* dir = env->get_chars(env, stack, obj_dir);
 
@@ -1087,8 +1093,8 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
 
-  void* obj_dir_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::DirStream", dir_stream, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_dir_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::DirStream", dir_stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_dir_stream;
   
@@ -1097,11 +1103,11 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__closedir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_dirp = stack[0].oval;
   if (!obj_dirp) {
-    return env->die(env, stack, "The $dirp object must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dirp object must be defined", __func__, FILE_NAME, __LINE__);
   }
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
@@ -1112,8 +1118,8 @@ int32_t SPVM__Sys__IO__closedir(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
 
-  env->set_field_byte_by_name(env, stack, obj_dirp, "closed", 1, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  env->set_field_byte_by_name(env, stack, obj_dirp, "closed", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
 
   stack[0].ival = status;
   
@@ -1122,11 +1128,11 @@ int32_t SPVM__Sys__IO__closedir(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__readdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_dirp = stack[0].oval;
   if (!obj_dirp) {
-    return env->die(env, stack, "The $dirp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dirp must be defined", __func__, FILE_NAME, __LINE__);
   }
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
@@ -1138,8 +1144,8 @@ int32_t SPVM__Sys__IO__readdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (dirent) {
-    void* obj_dirent = env->new_pointer_object_by_name(env, stack, "Sys::IO::Dirent", dirent, &e, __func__, FILE_NAME, __LINE__);
-    if (e) { return e; }
+    void* obj_dirent = env->new_pointer_object_by_name(env, stack, "Sys::IO::Dirent", dirent, &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
     stack[0].oval = obj_dirent;
   }
   else {
@@ -1154,7 +1160,7 @@ int32_t SPVM__Sys__IO__rewinddir(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_dirp = stack[0].oval;
   
   if (!obj_dirp) {
-    return env->die(env, stack, "The $dirp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dirp must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
@@ -1168,7 +1174,7 @@ int32_t SPVM__Sys__IO__telldir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirp = stack[0].oval;
   if (!obj_dirp) {
-    return env->die(env, stack, "The $dirp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dirp must be defined", __func__, FILE_NAME, __LINE__);
   }
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
@@ -1189,7 +1195,7 @@ int32_t SPVM__Sys__IO__seekdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_dirp = stack[0].oval;
   
   if (!obj_dirp) {
-    return env->die(env, stack, "The $dirp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dirp must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
@@ -1197,7 +1203,7 @@ int32_t SPVM__Sys__IO__seekdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t offset = stack[1].ival;
   
   if (!(offset >= 0)) {
-    return env->die(env, stack, "The $offset must be less than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$offset must be less than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   seekdir(dirp, offset);
@@ -1207,11 +1213,11 @@ int32_t SPVM__Sys__IO__seekdir(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_filename = stack[0].oval;
   if (!obj_filename) {
-    return env->die(env, stack, "The $filename must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$filename must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* filename = env->get_chars(env, stack, obj_filename);
 
@@ -1241,7 +1247,7 @@ int32_t SPVM__Sys__IO__access_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_pathname = stack[0].oval;
   
   if (!obj_pathname) {
-    return env->die(env, stack, "The $pathname must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$pathname must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* pathname = env->get_chars(env, stack, obj_pathname);
@@ -1280,7 +1286,7 @@ int32_t SPVM__Sys__IO__faccessat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_pathname = stack[1].oval;
   if (!obj_pathname) {
-    return env->die(env, stack, "The $pathname must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$pathname must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* pathname = env->get_chars(env, stack, obj_pathname);
   
@@ -1318,7 +1324,7 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
   return env->die(env, stack, "fcntl is not supported in this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
 #else
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t fd = stack[0].ival;
   
@@ -1338,8 +1344,8 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
       
       // Int
       if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && command_arg_type_dimension == 0) {
-        int32_t command_arg_int32 = env->get_field_int_by_name(env, stack, obj_command_arg, "value", &e, __func__, FILE_NAME, __LINE__);
-        if (e) { return e; }
+        int32_t command_arg_int32 = env->get_field_int_by_name(env, stack, obj_command_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
+        if (error_id) { return error_id; }
         
         ret = fcntl(fd, command, &command_arg_int32);
       }
@@ -1349,7 +1355,7 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
         ret = fcntl(fd, command, command_arg);
       }
       else {
-        return env->die(env, stack, "The $command_arg must be an Int object or the object that is a pointer class", __func__, FILE_NAME, __LINE__);
+        return env->die(env, stack, "$command_arg must be an Int object or the object that is a pointer class", __func__, FILE_NAME, __LINE__);
       }
     }
   }
@@ -1362,11 +1368,11 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e;
+  int32_t error_id = 0;
   
   void* obj_stream = stack[0].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   FILE* stream = (FILE*)env->get_pointer(env, stack, obj_stream);
@@ -1457,7 +1463,7 @@ int32_t SPVM__Sys__IO__ungetc(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   void* obj_stream = stack[1].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
@@ -1493,23 +1499,23 @@ int32_t SPVM__Sys__IO__fsync(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__freopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
   
   void* obj_mode = stack[1].oval;
   if (!obj_mode) {
-    return env->die(env, stack, "The $mode must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$mode must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* mode = env->get_chars(env, stack, obj_mode);
   
   void* obj_stream = stack[2].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
@@ -1530,7 +1536,7 @@ int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_stream = stack[0].oval;
   if (!obj_stream) {
-    return env->die(env, stack, "The $stream must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
   }
   FILE* stream = env->get_pointer(env, stack, obj_stream);
 
@@ -1548,10 +1554,10 @@ int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   if (buf) {
     if (!(size >= 0)) {
-      return env->die(env, stack, "The $size must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$size must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
     }
     if (!(size <= buf_length)) {
-      return env->die(env, stack, "The $size must be less than or equal to the length of the $buf", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$size must be less than or equal to the length of $buf", __func__, FILE_NAME, __LINE__);
     }
   }
   
@@ -1572,7 +1578,7 @@ int32_t SPVM__Sys__IO__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "The ioctl method in the Sys::IO class is not supported in this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t fd = stack[0].ival;
   
@@ -1622,7 +1628,7 @@ int32_t SPVM__Sys__IO__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
       ret = ioctl(fd, request, request_arg_ref);
     }
     else {
-      return env->die(env, stack, "The $request_arg_ref must be an byte[]/short[]/int[]/long[]/float[]/double[] type object or the object that is a pointer class", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$request_arg_ref must be an byte[]/short[]/int[]/long[]/float[]/double[] type object or the object that is a pointer class", __func__, FILE_NAME, __LINE__);
     }
   }
   
