@@ -26,7 +26,7 @@ int32_t SPVM__Sys__Time__time(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__localtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e;
+  int32_t error_id = 0;
   
   time_t time = (time_t)stack[0].lval;
   struct tm* st_tm = env->new_memory_stack(env, stack, sizeof(struct tm));
@@ -37,8 +37,8 @@ int32_t SPVM__Sys__Time__localtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   localtime_r(&time, st_tm);
 #endif
   
-  void* obj_time_info = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tm", st_tm, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_time_info = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tm", st_tm, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_time_info;
   
@@ -47,7 +47,7 @@ int32_t SPVM__Sys__Time__localtime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__gmtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e;
+  int32_t error_id = 0;
   
   time_t time = (time_t)stack[0].lval;
   struct tm* st_tm = env->new_memory_stack(env, stack, sizeof(struct tm));
@@ -58,8 +58,8 @@ int32_t SPVM__Sys__Time__gmtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   gmtime_r(&time, st_tm);
 #endif
   
-  void* obj_time_info = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tm", st_tm, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_time_info = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tm", st_tm, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_time_info;
   
@@ -125,7 +125,7 @@ int32_t SPVM__Sys__Time__clock_gettime(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_tp = env->get_pointer(env, stack, obj_tp);
   }
   else {
-    return env->die(env, stack, "The $tp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$tp must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = clock_gettime(clk_id, st_tp);
@@ -153,7 +153,7 @@ int32_t SPVM__Sys__Time__clock_getres(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_res = env->get_pointer(env, stack, obj_res);
   }
   else {
-    return env->die(env, stack, "The $res must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$res must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = clock_getres(clk_id, st_res);
@@ -184,7 +184,7 @@ int32_t SPVM__Sys__Time__setitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_new_value = env->get_pointer(env, stack, obj_new_value);
   }
   else {
-    return env->die(env, stack, "The $new_value must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$new_value must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   void* obj_old_value = stack[1].oval;
@@ -223,7 +223,7 @@ int32_t SPVM__Sys__Time__getitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_curr_value = env->get_pointer(env, stack, obj_curr_value);
   }
   else {
-    return env->die(env, stack, "The $curr_value must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$curr_value must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = getitimer(which, st_curr_value);
@@ -247,7 +247,7 @@ int32_t SPVM__Sys__Time__times(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_tms = stack[0].oval;
   
   if (!obj_tms) {
-    return env->die(env, stack, "The $tms must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$tms must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_tms);
@@ -291,7 +291,7 @@ int32_t SPVM__Sys__Time__clock_nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_request = env->get_pointer(env, stack, obj_request);
   }
   else {
-    return env->die(env, stack, "The $request must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$request must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_remain = stack[3].oval;
@@ -325,7 +325,7 @@ int32_t SPVM__Sys__Time__nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_rqtp = env->get_pointer(env, stack, obj_rqtp);
   }
   else {
-    return env->die(env, stack, "The $rqtp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$rqtp must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_rmtp = stack[1].oval;
